|
|
|
| Description |
| Utilities for doing I/O with ledger files.
|
|
| Synopsis |
|
|
|
| Documentation |
|
|
| Get the user's default ledger file path.
|
|
|
| Get the user's default timelog file path.
|
|
|
| Read the user's default ledger file, or give an error.
|
|
|
| Read the user's default timelog file, or give an error.
|
|
|
| Read a ledger from this file, with no filtering, or give an error.
|
|
|
| Read a ledger from this file, filtering according to the filter spec.,
| or give an error.
|
|
|
| Read a RawLedger from the given string, using the current time as
reference time, or give a parse error.
|
|
|
| Convert a RawLedger to a canonicalised, cached and filtered Ledger.
|
|
| Produced by Haddock version 2.7.2 |